@@ -3,7 +3,7 @@
  *  Copyright (c) 2006 Sam Hocevar <sam@zoy.org>
  *                All Rights Reserved
  *
- *  $Id: debug.h 59 2006-12-28 20:22:32Z sam $
+ *  $Id: debug.h 291 2007-07-06 13:34:38Z sam $
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
@@ -19,5 +19,9 @@
 extern void _zz_debug(const char *format, ...)
        __attribute__((__format__(__printf__, 1, 2)));
 
-#define debug _zz_debug
+#ifdef LIBZZUF
+#   define debug _zz_debug
+#else
+#   define debug(...)
+#endif
 
