@@ -3,7 +3,7 @@
  *  Copyright (c) 2006 Sam Hocevar <sam@zoy.org>
  *                All Rights Reserved
  *
- *  $Id: fuzz.h 292 2007-07-06 13:40:55Z sam $
+ *  $Id: fuzz.h 309 2007-11-02 22:45:54Z sam $
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
@@ -18,7 +18,8 @@
 
 extern void _zz_fuzzing(char const *);
 extern void _zz_bytes(char const *);
-extern void _zz_pick(char const *);
+extern void _zz_list(char const *);
+extern void _zz_ports(char const *);
 extern void _zz_protect(char const *);
 extern void _zz_refuse(char const *);
 
