@@ -6,7 +6,7 @@
  *                2007 Dominik Kuhlen <dominik.kuhlen#gmit-gmbh:de>
  *                All Rights Reserved
  *
- *  $Id: lib-fd.c 292 2007-07-06 13:40:55Z sam $
+ *  $Id: lib-fd.c 315 2007-11-03 00:08:43Z sam $
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
@@ -43,6 +43,9 @@
 #if defined HAVE_SYS_SOCKET_H
 #   include <sys/socket.h>
 #endif
+#if defined HAVE_NETINET_IN_H
+#   include <netinet/in.h>
+#endif
 #if defined HAVE_SYS_UIO_H
 #   include <sys/uio.h>
 #endif
@@ -82,6 +85,14 @@ static int     (*ORIG(open64))  (const char *file, int oflag, ...);
 static int     (*ORIG(accept))  (int sockfd, struct sockaddr *addr,
                                  SOCKLEN_T *addrlen);
 #endif
+#if defined HAVE_BIND
+static int     (*ORIG(bind))    (int sockfd, const struct sockaddr *my_addr,
+                                 SOCKLEN_T addrlen);
+#endif
+#if defined HAVE_CONNECT
+static int     (*ORIG(connect)) (int sockfd, const struct sockaddr *serv_addr,
+                                 SOCKLEN_T addrlen);
+#endif
 #if defined HAVE_SOCKET
 static int     (*ORIG(socket))  (int domain, int type, int protocol);
 #endif
@@ -167,12 +178,14 @@ int NEW(accept)(int sockfd, struct sockaddr *addr, SOCKLEN_T *addrlen)
 
     LOADSYM(accept);
     ret = ORIG(accept)(sockfd, addr, addrlen);
-    if(!_zz_ready || _zz_islocked(-1) || !_zz_network)
+    if(!_zz_ready || _zz_islocked(-1) || !_zz_network
+         || !_zz_iswatched(sockfd) || !_zz_isactive(sockfd))
         return ret;
 
     if(ret >= 0)
     {
-        debug("%s(%i, %p, %p) = %i", __func__, sockfd, addr, addrlen, ret);
+        debug("%s(%i, %p, &%i) = %i", __func__,
+              sockfd, addr, (int)*addrlen, ret);
         _zz_register(ret);
     }
 
@@ -180,6 +193,55 @@ int NEW(accept)(int sockfd, struct sockaddr *addr, SOCKLEN_T *addrlen)
 }
 #endif
 
+#if defined AF_INET6
+#   define case_AF_INET6 case AF_INET6:
+#else
+#   define case_AF_INET6
+#endif
+
+#define CONNECTION(fn, addr) \
+    do \
+    { \
+        LOADSYM(fn); \
+        ret = ORIG(fn)(sockfd, addr, addrlen); \
+        if(!_zz_ready || _zz_islocked(-1) || !_zz_network) \
+            return ret; \
+        if(ret >= 0) \
+        { \
+            const struct sockaddr_in* in = (const struct sockaddr_in *)addr; \
+            long int port; \
+            switch(addr->sa_family) \
+            { \
+            case AF_INET: \
+            case_AF_INET6 \
+                port = ntohs(in->sin_port); \
+                if(_zz_portwatched(port)) \
+                    break; \
+                /* Fall through */ \
+            default: \
+                _zz_unregister(sockfd); \
+                return ret; \
+            } \
+            debug("%s(%i, %p, %i) = %i", __func__, \
+                  sockfd, addr, (int)addrlen, ret); \
+        } \
+    } while(0);
+
+#if defined HAVE_BIND
+int NEW(bind)(int sockfd, const struct sockaddr *my_addr, SOCKLEN_T addrlen)
+{
+    int ret; CONNECTION(bind, my_addr); return ret;
+}
+#endif
+
+#if defined HAVE_CONNECT
+int NEW(connect)(int sockfd, const struct sockaddr *serv_addr,
+                 SOCKLEN_T addrlen)
+{
+    int ret; CONNECTION(connect, serv_addr); return ret;
+}
+#endif
+
 #if defined HAVE_SOCKET
 int NEW(socket)(int domain, int type, int protocol)
 {
@@ -251,12 +313,13 @@ RECV_T NEW(recvfrom)(int s, void *buf, size_t len, int flags,
         _zz_addpos(s, ret);
 
         if(ret >= 4)
-            debug("%s(%i, %p, %li, 0x%x, %p, %p) = %i \"%c%c%c%c...", __func__,
-                  s, buf, (long int)len, flags, from, fromlen, ret,
-                  b[0], b[1], b[2], b[3]);
+            debug("%s(%i, %p, %li, 0x%x, %p, &%i) = %i \"%c%c%c%c...",
+                  __func__, s, buf, (long int)len, flags, from, (int)*fromlen,
+                  ret, b[0], b[1], b[2], b[3]);
         else
-            debug("%s(%i, %p, %li, 0x%x, %p, %p) = %i \"%c...", __func__,
-                  s, buf, (long int)len, flags, from, fromlen, ret, b[0]);
+            debug("%s(%i, %p, %li, 0x%x, %p, &%i) = %i \"%c...",
+                  __func__, s, buf, (long int)len, flags, from, (int)*fromlen,
+                  ret, b[0]);
     }
     else
         debug("%s(%i, %p, %li, 0x%x, %p, %p) = %i", __func__,
