@@ -3,7 +3,7 @@
  *  Copyright (c) 2006 Sam Hocevar <sam@zoy.org>
  *                All Rights Reserved
  *
- *  $Id: libzzuf.c 292 2007-07-06 13:40:55Z sam $
+ *  $Id: libzzuf.c 309 2007-11-02 22:45:54Z sam $
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
@@ -90,9 +90,13 @@ void _zz_init(void)
     if(tmp && *tmp)
         _zz_bytes(tmp);
 
-    tmp = getenv("ZZUF_PICK");
+    tmp = getenv("ZZUF_LIST");
     if(tmp && *tmp)
-        _zz_pick(tmp);
+        _zz_list(tmp);
+
+    tmp = getenv("ZZUF_PORTS");
+    if(tmp && *tmp)
+        _zz_ports(tmp);
 
     tmp = getenv("ZZUF_PROTECT");
     if(tmp && *tmp)
