@@ -3,7 +3,7 @@
  *  Copyright (c) 2002, 2007 Sam Hocevar <sam@zoy.org>
  *                All Rights Reserved
  *
- *  $Id: opts.c 301 2007-07-10 15:23:18Z sam $
+ *  $Id: opts.c 309 2007-11-02 22:45:54Z sam $
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
@@ -33,7 +33,7 @@
 
 void _zz_opts_init(struct opts *opts)
 {
-    opts->fuzzing = opts->bytes = opts->pick = NULL;
+    opts->fuzzing = opts->bytes = opts->list = opts->ports = NULL;
     opts->protect = opts->refuse = NULL;
     opts->seed = DEFAULT_SEED;
     opts->endseed = DEFAULT_SEED + 1;
