@@ -3,7 +3,7 @@
  *  Copyright (c) 2002, 2007 Sam Hocevar <sam@zoy.org>
  *                All Rights Reserved
  *
- *  $Id: opts.h 301 2007-07-10 15:23:18Z sam $
+ *  $Id: opts.h 309 2007-11-02 22:45:54Z sam $
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
@@ -20,7 +20,7 @@ struct opts
 {
     char **oldargv;
     char **newargv;
-    char *fuzzing, *bytes, *pick, *protect, *refuse;
+    char *fuzzing, *bytes, *list, *ports, *protect, *refuse;
     uint32_t seed;
     uint32_t endseed;
     double minratio;
